.. AUTO-GENERATED FILE -- DO NOT EDIT!

bart.particle_tree
==================

Module: :mod:`bart.particle_tree`
---------------------------------
Inheritance diagram for ``ISLP.bart.particle_tree``:

.. inheritance-diagram:: ISLP.bart.particle_tree 
   :parts: 3

.. automodule:: ISLP.bart.particle_tree

.. currentmodule:: ISLP.bart.particle_tree

Class
-----

:class:`ParticleTree`
---------------------


.. autoclass:: ParticleTree
  :members:
  :undoc-members:
  :show-inheritance:
  :inherited-members:

  .. automethod:: __init__

Functions
---------


.. autofunction:: ISLP.bart.particle_tree.discrete_uniform_sampler


.. autofunction:: ISLP.bart.particle_tree.get_new_idx_data_points


.. autofunction:: ISLP.bart.particle_tree.grow_tree

